Introduction
::::::::::::

.. toctree::
    :maxdepth: 2

    Objectives.rst
    GettingStarted.rst
    WhatIsComputerScience.rst
    WhatIsProgramming.rst
    WhyStudyDataStructuresandAbstractDataTypes.rst
    WhyStudyAlgorithms.rst
    ReviewofBasicPython.rst
    GettingStartedwithData.rst
    InputandOutput.rst
    ControlStructures.rst
    ExceptionHandling.rst
    DefiningFunctions.rst
    ObjectOrientedProgramminginPythonDefiningClasses.rst
    Summary.rst
    KeyTerms.rst
    Exercises.rst
